#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'numpy>=1.9',
    'scipy>=0.15',
    'Cython>=0.25.2',
    'scikit-image>=0.12.3',
    'pandas>=0.19.2',
    'seaborn>=0.7.1',
    'javabridge>=1.0.15',
    'python-bioformats>=1.0.8'
]

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest', ]

setup(
    author="Keith Schulze",
    author_email='keith.schulze@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Tools for analysing mitochondrial distribution in fluoresence microscopy images",
    entry_points={
        'console_scripts': [
            'mito=mito.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + "\n" + history,
    include_package_data=True,
    keywords='mito',
    name='mito',
    packages=find_packages(include=['mito']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/keithschulze/mito',
    version='0.2.0',
    zip_safe=False,
)
